Welcome to resqpy's documentation
=================================

resqpy is a pure Python package which provides a programming interface (API) for
reading, writing, and modifying reservoir models in the RESQML format. It gives
you the ability to work with reservoir models programmatically, without having
to know the details of the RESQML standard.

resqpy is written and maintained by bp, and is made available under the MIT
license as a contribution to the open-source community.

The repository is hosted on `GitHub <https://github.com/bp/resqpy>`_.

.. toctree::
   :maxdepth: 1
   :caption: About

   installation
   CONTRIBUTING
   trademarks

.. toctree::
   :maxdepth: 2
   :caption: User guide

   getting-started
   tutorial/tutorial_index

API Reference
-------------

.. automodule:: resqpy


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
